@@ -31,8 +31,8 @@
 CachedCatalog::CachedCatalog()
 	: KatapultCatalog()
 {
-	cache.setAutoDelete(TRUE);
-	results.setAutoDelete(FALSE);
+	cache.setAutoDelete(true);
+	results.setAutoDelete(false);
 }
 
 CachedCatalog::~CachedCatalog()
@@ -114,7 +114,7 @@ Match CachedCatalog::queryItem(const KatapultItem *item, TQString query) const
 	TQStringList::Iterator wit = words.begin();
 	for(TQStringList::Iterator qit = queryWords.begin(); qit != queryWords.end(); ++qit) {
 		TQString queryWord = *qit;
-		bool didMatch = FALSE;
+		bool didMatch = false;
 		for(; wit != words.end(); ++wit) {
 			TQString word = *wit;
 			if(word.startsWith(queryWord)) {
@@ -125,7 +125,7 @@ Match CachedCatalog::queryItem(const KatapultItem *item, TQString query) const
 				} else {
 					_matched += word.length();
 				}
-				didMatch = TRUE;
+				didMatch = true;
 				break;
 			}
 			if(wordNo == 0) {
@@ -134,7 +134,7 @@ Match CachedCatalog::queryItem(const KatapultItem *item, TQString query) const
 				_matched += word.length();
 			}
 		}
-		if(didMatch == FALSE) {
+		if(!didMatch) {
 			return Match();
 		}
 		wordNo++;
