@@ -32,7 +32,7 @@ class TDEConfigBase;
 /**
 @author Joe Ferris
 */
-class KDE_EXPORT KatapultCatalog : public TQObject {
+class TDE_EXPORT KatapultCatalog : public TQObject {
 	TQ_OBJECT
   
 
