@@ -34,9 +34,9 @@
 
 #include "settings.h"
 #include "execcatalog.h"
-#include "actionregistry.h"
+#include <actionregistry.h>
 #include "actionrun.h"
-#include "status.h"
+#include <status.h>
 
 K_EXPORT_COMPONENT_FACTORY( katapult_execcatalog,
                             KGenericFactory<ExecCatalog>( "katapult_execcatalog" ) )
@@ -97,7 +97,7 @@ TQWidget * ExecCatalog::configure()
 	ExecCatalogSettings* settings = new ExecCatalogSettings();
 
 	settings->triggerWordLE->setText(_triggerWord);
-	connect(settings->triggerWordLE, TQT_SIGNAL(textChanged(const TQString&)), this, TQT_SLOT(triggerWordChanged(const TQString&)));
+	connect(settings->triggerWordLE, TQ_SIGNAL(textChanged(const TQString&)), this, TQ_SLOT(triggerWordChanged(const TQString&)));
 
 	settings->introLabel->setText(i18n("Use with \"%1 exec query\"").arg(_triggerWord));
 
