@@ -27,7 +27,7 @@
  */
 class o2Display : public ImageDisplay
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 	public:
 		o2Display(TQWidget *, const char *, const TQStringList&);
